@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Scripts.pm,v 1.9 2010-11-26 21:04:33 dpchrist Exp $
+# $Id: Scripts.pm,v 1.10 2010-11-27 03:37:59 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -9,7 +9,7 @@ package Dpchrist::Scripts;
 use strict;
 use warnings;
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.9 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.10 $ =~ /(\d+)/g);
 
 1;
 
@@ -24,7 +24,7 @@ Dpchrist::Scripts - Perl scripts by David Christensen
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.9 $.
+This documentation describes module revision $Revision: 1.10 $.
 
 
 This is alpha test level software
@@ -34,6 +34,36 @@ and may change or disappear at any time.
 Perl scripts that I haven't turned into modules (yet).
 
 
+=head1 INSTALLATION
+
+Old school:
+
+    $ perl Makefile.PL
+    $ make    
+    $ make test
+    $ make install 
+
+Minimal:
+
+    $ cpan Dpchrist::Scripts
+
+Complete:
+
+    $ cpan Bundle::Dpchrist
+
+The following warning may be safely ignored:
+
+    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
+    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
+    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
+    /usr/local/lib/site_perl .) at Makefile.PL line 22.
+
+
+=head2 PREREQUISITES
+
+See Makefile.PL in the source distribution root directory.
+
+
 =head1 SEE ALSO
 
     man findpmr
